\name{coxphGPLE}
\alias{coxphGPLE}
\title{Evaluation of functional covariate}
\usage{
GPLE(zdata0, w, ww, w3w, y0, trunk0, status0, GBETA0, DGBETA0, 2, n0*h, 10,0.05,500)

GPLE_para(xdata0, zdata0, y0, trunk0, status0, alpha0, aalpha0, a3alpha0, w,ww,w3w, GBETA0, DGBETA0, 0.2,2, n0*h1, n0*h, 0.01,500)

}
\description{
Evaluation of functional covariate environment interaction in the cox model.
}
\examples{
rm(list=ls())
library(survival)
library(coxphGPLE)
samp = 3

data(d1)
delta = (d1$PUBIC>=2)

data_o = data.frame(time = d1$AGE, delta = delta, d1[, c(8, 9, 15, 16:26)])
data1 = list(time = data_o$time, delta = data_o$delta, zdata = cbind(1, scale(data_o$PARITY), scale(data_o$CHEIGHT)),
             xdata = scale(log(cbind(data_o$MEP_T3, data_o$MBP_T3, data_o$MCPP_T3))))

xdata = data1$xdata
zdata = data1$zdata
trunk = 0 * data1$time
y = data1$time
status = data1$delta

##########initial value#########
data(data2)
 GBETAf <- data2[,1:3]
DGBETAf <- data2[,4:6]
 alphaf <- unique(data2$alpha1)
aalphaf <- unique(data2$aalpha1)
a3alphaf = unique(data2$a3alpha1)
wf = data2$w
wwf = data2$ww
w3wf = data2$w3w

p = dim(zdata)[[2]]
q = dim(xdata)[[2]]

n = nrow(xdata)

grid1 = seq(min(wf), max(wf), length = 500)
grid2 = seq(min(wwf), max(wwf), length = 500)
grid3 = seq(min(w3wf), max(w3wf), length = 500)

h1 = c(0.9, 0.9, 0.9)
h<-c(0.9, 0.5, 0.5)

#nboots = 5
bootsBETA1 = bootsBETA2 = bootsBETA3 = rep(NA, length(grid1))
bootsALPHA = bootsAALPHA = bootsA3ALPHA = rep(NA, 3)

#for(samp in 2:2){
  #samp = nsamp[sampp]
  print(samp)
  set.seed(samp)
  INDEX<-sample(1:n,n,T,rep(1,n)/n)
  #print(INDEX)

  INDEX<-na.omit(INDEX)
  zdata0<-zdata[INDEX,]
  y0<-y[INDEX]
  trunk0<- trunk[INDEX]
  status0<- status[INDEX]
  xdata0<-xdata[INDEX,]
  n0 = length(y0)

  w1 <- wf
  ww1 <- wwf
  w3w1 = w3wf

  alpha0<-alphaf
  aalpha0<-aalphaf
  a3alpha0 = a3alphaf

  GBETA0 = GBETAf
  DGBETA0 = DGBETAf
  GBETA1 <- GBETA0 + 1
  smooth1<-loess(GBETA0[,1] ~w1, span = 1/10, degree = 2)
  smooth2<-loess(GBETA0[,2] ~ww1, span = 1/10, degree = 2)
  smooth3 = loess(GBETA0[, 3] ~ w3w1, span = 1/10, degree = 2)

  dsmooth1<-loess(DGBETA0[,1] ~w1, span = 1/10, degree = 2)
  dsmooth2<-loess(DGBETA0[,2] ~ww1, span = 1/10, degree = 2)
  dsmooth3 = loess(DGBETA0[, 3] ~ w3w1, span = 1/10, degree = 2)


  alpha1<-alpha0+1
  aalpha1<-aalpha0+1
  a3alpha1 = a3alpha0 + 1
  rr0<-1
  d0 = 0
  d1 = d0 + 1

  while((d1>0.1)&(abs(d1-d0)>1e-3))
  {

    d0 = max(abs(alpha1-alpha0))+max(abs(aalpha1-aalpha0))+max(abs(a3alpha1-a3alpha0))+max(abs(GBETA1-GBETA0))
    alpha1<-alpha0
    aalpha1<-aalpha0
    a3alpha1<-a3alpha0

    GBETA1 <- GBETA0
    DGBETA1 = DGBETA0
    w<-c(xdata0 %*% alpha0)
    ww<-c(xdata0 %*% aalpha0)
    w3w<-c(xdata0 %*% a3alpha0)

    link1<-predict(smooth1,w)
    link1[w<min(w1)]<-GBETA0[,1][order(w1)][1]
    link1[w>max(w1)]<-GBETA0[,1][order(-w1)][1]

    link2<-predict(smooth2,ww)
    link2[ww<min(ww1)]<-GBETA0[,2][order(ww1)][1]
    link2[ww>max(ww1)]<-GBETA0[,2][order(-ww1)][1]

    link3<-predict(smooth3, w3w)
    link3[w3w<min(w3w1)]<-GBETA0[,3][order(w3w1)][1]
    link3[w3w>max(w3w1)]<-GBETA0[,3][order(-w3w1)][1]

    GBETA0 <- cbind(link1,link2, link3)

    link1<-predict(dsmooth1,w)
    link1[w<min(w1)]<-DGBETA0[,1][order(w1)][1]
    link1[w>max(w1)]<-DGBETA0[,1][order(-w1)][1]

    link2<-predict(dsmooth2,ww)
    link2[ww<min(ww1)]<-DGBETA0[,2][order(ww1)][1]
    link2[ww>max(ww1)]<-DGBETA0[,2][order(-ww1)][1]

    link3<-predict(dsmooth3, w3w)
    link3[w3w<min(w3w1)]<-DGBETA0[,3][order(w3w1)][1]
    link3[w3w>max(w3w1)]<-DGBETA0[,3][order(-w3w1)][1]

    DGBETA0 <- cbind(link1, link2, link3)

    GBETA12<-GPLE(zdata0, w, ww, w3w, y0, trunk0, status0, GBETA0, DGBETA0, 2, n0*h, 10,0.05,500)

    GBETA0 <- GBETA12[[1]]
    #GBETA[,1]<-GBETA[,1]-mean(GBETA[,1])
    par(mfrow=c(1,3))
    plot(sort(w),GBETA0[,1][order(w)],type="l")
    plot(sort(ww),GBETA0[,2][order(ww)],type="l")
    plot(sort(w3w),GBETA0[,3][order(w3w)],type="l")

    w1<-w
    ww1<-ww
    w3w1 = w3w
    smooth1<-loess(GBETA0[,1] ~w1, span = 1/10, degree = 2)
    smooth2<-loess(GBETA0[,2] ~ww1, span = 1/10, degree = 2)
    smooth3 = loess(GBETA0[, 3] ~ w3w1, span = 1/10, degree = 2)

    DGBETA0 <- GBETA12[[2]]
    dsmooth1<-loess(DGBETA0[,1] ~w1, span = 1/10, degree = 2)
    dsmooth2<-loess(DGBETA0[,2] ~ww1, span = 1/10, degree = 2)
    dsmooth3 = loess(DGBETA0[, 3] ~ w3w1, span = 1/10, degree = 2)

    re<-GPLE_para(xdata0, zdata0, y0, trunk0, status0, alpha0, aalpha0, a3alpha0,
                  w,ww,w3w, GBETA0, DGBETA0, 0.2,2, n0*h1, n0*h, 0.01,500)

    alpha0<-re[1:q]
    aalpha0<-re[(q+1):(2*q)]
    a3alpha0 = re[(2*q+1):(3*q)]

    d1 = max(abs(alpha1-alpha0))+max(abs(aalpha1-aalpha0))+max(abs(a3alpha1-a3alpha0)) + max(abs(GBETA1 - GBETA0))
    print(max(abs(alpha1-alpha0))+max(abs(aalpha1-aalpha0))+max(abs(a3alpha1-a3alpha0)) + max(abs(GBETA1 - GBETA0)))
    print(max(abs(alpha1-alpha0))+max(abs(aalpha1-aalpha0))+max(abs(a3alpha1-a3alpha0)))
    rr0<-rr0+1
    if(rr0 == 100)
    {
      break
    }

  }
  if(rr0<100){
    link1<-predict(smooth1,grid1)
    link1[grid1 < min(w1)]<-GBETA1[,1][order(w1)][1]
    link1[grid1 > max(w1)]<-GBETA1[,1][order(-w1)][1]
    bootsBETA1<- link1

    link2<-predict(smooth2, grid2)
    link2[grid2 < min(ww1)]<-GBETA1[,2][order(ww1)][1]
    link2[grid2 > max(ww1)]<-GBETA1[,2][order(-ww1)][1]
    bootsBETA2<- link2

    link3<-predict(smooth3, grid3)
    link3[grid3 < min(w3w1)]<-GBETA1[, 3][order(w3w1)][1]
    link3[grid3 > max(w3w1)]<-GBETA1[, 3][order(-w3w1)][1]
    bootsBETA3<- link3


    bootsALPHA<-alpha0
    bootsAALPHA<-aalpha0
    bootsA3ALPHA = a3alpha0
  }
  samp <- samp +1

  save(bootsBETA1, bootsBETA2, bootsBETA3, bootsALPHA, bootsAALPHA, bootsA3ALPHA,
       file = paste("re_prop_h09h05f09boot", samp, ".RData", sep = ""))
}
